/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */
package com.bsf.lovDemo.util.help;

import com.bsf.lovDemo.views.Resources;
import com.jgoodies.swing.application.ResourceManager;

import javax.swing.Icon;
import javax.swing.tree.DefaultMutableTreeNode;
import java.net.URL;

/**
 * Instances of this class define help nodes in the dynamic help.
 * A help node is either a chapter or topic, where only topics have
 * an attached URL.
 */
public final class HelpNode extends DefaultMutableTreeNode {
    public static final int CHAPTER_ITEM = 0;
    public static final int TOPIC_ITEM = 1;

    private int _type;
    private String _name;
    private URL _url = null;

    /**
     * Constructs a <code>HelpNode</code> with the given _name, _type, and URL.
     */
    private HelpNode( String p_name, int p_type, String p_url ) {
        super();

        _name = p_name;
        _type = p_type;

        if ( p_url != null ) {
            _url = ResourceManager.getURL( p_url );
        }
    }

    /**
     * Creates and answers a chapter help node with the given _name.
     */
    static HelpNode createChapter( String p_name ) {
        return new HelpNode( p_name, CHAPTER_ITEM, null );
    }

    /**
     * Creates and answers a topic help node with the given _name and p_url.
     */
    static HelpNode createTopic( String p_name, String p_url ) {
        return new HelpNode( p_name, TOPIC_ITEM, p_url );
    }

    /**
     * Creates and answers an help root node, new one each time.
     */
    static HelpNode getRootNode() {
        return createChapter( "rootNode" );
    }

    public boolean isChapter() {
        return _type == CHAPTER_ITEM;
    }

    public String toString() {
        return _name;
    }

    public URL getURL() {
        return _url;
    }

    boolean matches( URL aUrl ) {
        return aUrl.equals( getURL() );
    }

    public Icon getIcon( boolean sel ) {
        return isChapter() ? Resources.BOOK_ICON : Resources.TOPIC_ICON;
    }
}