/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */

package com.bsf.lovDemo.views.internalFrames;

import com.bsf.lovDemo.components.LovBox;
import com.bsf.lovDemo.components.LovFieldSelectPanel;
import com.bsf.lovDemo.controllers.DemoController;
import com.bsf.lovDemo.models.AvailableLovs;
import com.bsf.lovDemo.models.Person;
import com.bsf.lovDemo.util.HelpSelectionMouseListener;
import com.bsf.lovDemo.util.help.HelpTreeModel;
import com.bsf.lovDemo.views.DemoFrame;
import com.jgoodies.forms.factories.DefaultComponentFactory;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.swing.application.ResourceManager;
import com.jgoodies.swing.application.Workbench;
import com.jgoodies.swing.panels.GradientBackgroundPanel;
import com.jgoodies.swing.panels.SimpleInternalFrame;
import com.jgoodies.swing.util.UIFactory;

import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * Provides the InternalFrame for the ComboBoxes illustration.
 */
public final class ComboBoxesInternalFrame extends SimpleInternalFrame implements ActionListener {
    private Person _person = null;
    private LovBox _countryBox = null;
    private JLabel _countryLabel = null;
    private LovFieldSelectPanel _countrySelectPanel = null;

    // *************************************************************************
    // ***************************** Constructors ******************************
    // *************************************************************************

    /**
     * Constructs a module displaying the usage of LOVs in a Table.
     */
    public ComboBoxesInternalFrame() {
        super( ResourceManager.getString( "comboboxes.title" ) );

        // We want this interfnal frame to appear selected
        setSelected( true );

        // We set the content of this internal frame
        setContent( buildContentPanel() );
    }

    // *************************************************************************
    // *************************** Design Methods ******************************
    // *************************************************************************

    /**
     * Builds and returns the content panel.
     */
    private JComponent buildContentPanel() {
        _person = DemoController.getInstance().getModel().getPersonObject();

        JLabel refLabel = new JLabel( ResourceManager.getString( "ref.label" ) );
        JTextField refField = new JTextField( _person.getRef() );
        refField.setEnabled( false );

        JLabel nameLabel = new JLabel( ResourceManager.getString( "name.label" ) );
        JTextField nameField = new JTextField( _person.getName() );
        nameField.setEnabled( false );

        try {
            // We set the LOV as well...
            _countryLabel = new JLabel( ResourceManager.getString( "country.label" ) );
            _countryBox = new LovBox( AvailableLovs.LOV_COUNTRIES, AvailableLovs.LOV_COUNTRIES_LONG_NAME );

            // Initialization
            _countryBox.setSelectedLovValue( _person.getCountryID() );

            _countryBox.addActionListener( new ActionListener() {
                public void actionPerformed( ActionEvent e ) {
                    // We only store the country OID in the person object
                    _person.setCountryID( _countryBox.getSelectedLovValueOID() );
                }
            } );
        } catch( Exception e ) {
            // We'll never reach this panel if the lov aren't available...
        }

        JPanel contentPanel = new JPanel( new FormLayout( "right:pref:none, 5dlu, fill:105dlu:none",
                                                          "center:pref:none, 2dlu, center:pref:none, 2dlu, center:pref:none, 2dlu" ) );

        contentPanel.addMouseListener( new HelpSelectionMouseListener( HelpTreeModel.DETAIL_WHY_AND_HOW ) );

        CellConstraints cc = new CellConstraints();
        contentPanel.add( refLabel, cc.xy( 1, 1 ) );
        contentPanel.add( refField, cc.xy( 3, 1 ) );
        contentPanel.add( nameLabel, cc.xy( 1, 3 ) );
        contentPanel.add( nameField, cc.xy( 3, 3 ) );
        contentPanel.add( _countryLabel, cc.xy( 1, 5 ) );
        contentPanel.add( _countryBox, cc.xy( 3, 5 ) );

        contentPanel.setOpaque( false );

        JComponent separator = DefaultComponentFactory.getInstance().createSeparator( ResourceManager.getString( "person.title" ) );
        separator.setOpaque( false );

        _countrySelectPanel = new LovFieldSelectPanel( this,
                                                       ResourceManager.getString( "combobox.country.field.selection" ),
                                                       TableInternalFrame.COUNTRY_FIELDS,
                                                       TableInternalFrame.COUNTRY_FIELDS_LABEL,
                                                       1 );

        GradientBackgroundPanel enclosingPanel = new GradientBackgroundPanel( true );
        enclosingPanel.setLayout( new FormLayout( "4dlu, pref:grow, 4dlu",
                                                  "2dlu, pref:none, 4dlu, top:pref:none, 4dlu, top:pref:none, 2dlu" ) );

        enclosingPanel.add( separator, cc.xy( 2, 2 ) );
        enclosingPanel.add( contentPanel, cc.xy( 2, 4 ) );
        enclosingPanel.add( _countrySelectPanel, cc.xy( 2, 6 ) );

        return UIFactory.createStrippedScrollPane( enclosingPanel );
    }

    /**
     * This action performed is called by the various SelectPanels.
     */
    public void actionPerformed( ActionEvent e ) {
        // We update the selected help node (only when an action occurs)
        ( (DemoFrame) Workbench.getMainFrame() ).setDisplayedHelpNodeInHelpContent( HelpTreeModel.DETAIL_FIELD_SELECTION );

        _countryBox.getLovBoxRenderer().setField( _countrySelectPanel.getSelectedField() );

        // We have to update the UI
        _countryBox.repaint();
    }
}
