/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */

package com.bsf.lovDemo.views.internalFrames;

import com.bsf.lovDemo.components.LovCellRenderer;
import com.bsf.lovDemo.components.LovFieldSelectPanel;
import com.bsf.lovDemo.controllers.DemoController;
import com.bsf.lovDemo.models.AvailableLovs;
import com.bsf.lovDemo.util.HelpSelectionMouseListener;
import com.bsf.lovDemo.util.help.HelpTreeModel;
import com.bsf.lovDemo.views.DemoFrame;
import com.jgoodies.forms.factories.DefaultComponentFactory;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.swing.application.ResourceManager;
import com.jgoodies.swing.application.Workbench;
import com.jgoodies.swing.panels.GradientBackgroundPanel;
import com.jgoodies.swing.panels.SimpleInternalFrame;
import com.jgoodies.swing.util.UIFactory;

import javax.swing.*;
import javax.swing.table.TableColumn;
import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

/**
 * Provides the LovTable view using a <code>SimpleInternalFrame</code>.
 */
public final class TableInternalFrame extends SimpleInternalFrame implements ActionListener {
    public static final String[] COUNTRY_FIELDS = {AvailableLovs.LOV_COUNTRIES_SHORT_NAME,
                                                   AvailableLovs.LOV_COUNTRIES_LONG_NAME};

    public static final String[] COUNTRY_FIELDS_LABEL = {"Short Name",
                                                         "Long Name"};

    public static final Color NO_MOUSE_BG_COLOR = new Color( 173, 193, 238 );
    public static final Color MOUSE_OVER_BG_COLOR = new Color( 128, 163, 242 );

    private static final int COUNTRY_COLUMN_INDEX = 2;

    private JTable _customerTable = null;
    private JButton _toggleButton = null;
    private boolean _isLovRendererOn = false;
    private LovCellRenderer _countryCellRenderer;
    private LovFieldSelectPanel _countrySelectPanel = null;

    // *************************************************************************
    // ***************************** Constructors ******************************
    // *************************************************************************

    /**
     * Constructs a module displaying the usage of LOVs in a Table.
     */
    public TableInternalFrame() {
        super( ResourceManager.getString( "table.title" ) );

        // We want this interfnal frame to appear selected
        setSelected( true );

        // We set the content of this internal frame
        setContent( buildContentPanel() );

        // We intialize the cell renderers
        initializeCellRenderers();
    }

    // *************************************************************************
    // *************************** Design Methods ******************************
    // *************************************************************************

    /**
     * Builds and returns the content panel.
     */
    private JComponent buildContentPanel() {
        GradientBackgroundPanel contentPanel = new GradientBackgroundPanel( true );

        _customerTable = new JTable( DemoController.getInstance().getModel().getPersonTableModel() );
        _customerTable.setOpaque( true );
        _customerTable.setAutoResizeMode( JTable.AUTO_RESIZE_SUBSEQUENT_COLUMNS );
        _customerTable.addMouseListener( new HelpSelectionMouseListener( HelpTreeModel.TABLE_WHY_AND_HOW ) );

        JScrollPane scrollPane = UIFactory.createStrippedScrollPane( _customerTable );
        scrollPane.setOpaque( false );
        scrollPane.getViewport().setOpaque( false );

        JComponent tableSeparator = DefaultComponentFactory.getInstance().createSeparator( ResourceManager.getString( "table.titled.border" ) );
        tableSeparator.setOpaque( false );

        // Default state is lov renderers off
        _toggleButton = getButton( ResourceManager.getString( "table.toggle.off" ) );
        _toggleButton.addActionListener( this );

        _countrySelectPanel = new LovFieldSelectPanel( this,
                                                       _toggleButton,
                                                       ResourceManager.getString( "table.country.display.field" ),
                                                       COUNTRY_FIELDS,
                                                       COUNTRY_FIELDS_LABEL,
                                                       1 );

        _countrySelectPanel.setEnabled( false ); // Default case, LovRenderer off...

        CellConstraints cc = new CellConstraints();
        contentPanel.setLayout( new FormLayout( "3dlu, fill:130dlu:none, left:pref:grow, 3dlu",
                                                "2dlu, pref:none, 4dlu, top:80dlu:none, 4dlu, top:pref:grow" ) );
        contentPanel.add( tableSeparator, cc.xywh( 2, 2, 2, 1 ) );
        contentPanel.add( scrollPane, cc.xywh( 2, 4, 2, 1 ) );
        contentPanel.add( _countrySelectPanel, cc.xywh( 2, 6, 2, 1 ) );

        return UIFactory.createStrippedScrollPane( contentPanel );
    }

    private void initializeCellRenderers() {
        // We want the rendering to be faster so we "preloaded" the LOVs
        // while launching the application (cd. LOVDemo)
        _countryCellRenderer = new LovCellRenderer( AvailableLovs.LOV_COUNTRIES,
                                                    AvailableLovs.LOV_COUNTRIES_LONG_NAME,
                                                    AvailableLovs.LOV_COUNTRIES_LONG_NAME );
    }

    public void toggleLovRenderer() {
        String toggleButtonText = null;
        TableColumn countryColumn = _customerTable.getColumnModel().getColumn( COUNTRY_COLUMN_INDEX );

        // It's a toggle... State changed...
        _isLovRendererOn = !_isLovRendererOn;

        if ( _isLovRendererOn ) {
            // We instrall the LovRenderers and change the button text
            countryColumn.setCellRenderer( _countryCellRenderer );
            toggleButtonText = ResourceManager.getString( "table.toggle.on" );
        } else {
            // We must restore the default renderer (as a String, we don't bother) and button text
            toggleButtonText = ResourceManager.getString( "table.toggle.off" );
            countryColumn.setCellRenderer( _customerTable.getDefaultRenderer( String.class ) );
        }

        // We change the label of the button
        _toggleButton.setText( toggleButtonText );

        // And enable (if ON) or disable (if OFF) the SelectPanel
        _countrySelectPanel.setEnabled( _isLovRendererOn );

        // Since the renderers have changed...
        _customerTable.repaint();
    }

    // *************************************************************************
    // ******************************* Accessors *******************************
    // *************************************************************************

    /**
     * Creates and answers a JButton with the specified text.
     */
    public static JButton getButton( String p_text ) {
        JButton button = new JButton( p_text );
        button.setOpaque( true );
        button.setFocusPainted( false );
        button.setBorderPainted( true );
        button.setBackground( NO_MOUSE_BG_COLOR );
        button.setHorizontalAlignment( SwingConstants.CENTER );
        button.setHorizontalTextPosition( SwingConstants.CENTER );

        button.addMouseListener( new MouseAdapter() {
            public void mouseEntered( MouseEvent e ) {
                ( (JButton) e.getSource() ).setBackground( MOUSE_OVER_BG_COLOR );
            }

            public void mouseExited( MouseEvent e ) {
                ( (JButton) e.getSource() ).setBackground( NO_MOUSE_BG_COLOR );
            }
        } );

        return button;
    }

    // *************************************************************************
    // **************************** Action Listeners ***************************
    // *************************************************************************

    public void actionPerformed( ActionEvent e ) {
        if ( e.getSource() == _toggleButton ) {
            toggleLovRenderer();
        }

        // Changing the renderer
        _countryCellRenderer.setDisplayedField( _countrySelectPanel.getSelectedField() );

        // We update the selected help node (only when an action occurs)
        ( (DemoFrame) Workbench.getMainFrame() ).setDisplayedHelpNodeInHelpContent( HelpTreeModel.TABLE_FIELD_SELECTION );

        // The fields for the rendering of the LOV have changed... We must
        // reflect the change in the table
        _customerTable.repaint();
    }
}