/**
 * Copyright (c) 2002 Bright Side Factory.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Bright Side Factory (http://www.bs-factory.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Bright Side", "BS Factory" and "Bright Side Factory" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@bs-factory.org.
 *
 * 5. Products derived from this software may not be called "Bright Side",
 *    nor may "Bright Side" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Bright Side Factory.  For more
 * information on the Bright Side Factory, please see
 * <http://www.bs-factory.org/>.
 */
package com.bsf.lovDemo.views.internalFrames;

import com.bsf.lovDemo.util.BrowserLauncher;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.swing.application.ResourceManager;
import com.jgoodies.swing.panels.GradientBackgroundPanel;
import com.jgoodies.swing.panels.SimpleInternalFrame;
import com.jgoodies.swing.util.UIFactory;

import javax.swing.JComponent;
import javax.swing.JEditorPane;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;
import java.net.URL;

/**
 * This panel is displayed after a successful application startup
 * to welcome the user. It provides access to actions that are
 * most useful at the application start.
 */
public final class WelcomeInternalFrame extends SimpleInternalFrame {
    /**
     * Constructs a <code>WelcomeInternalFrame</code>.
     */
    public WelcomeInternalFrame() {
        super( ResourceManager.getString( "welcome.title" ) );

        // We want this interfnal frame to appear selected
        setSelected( true );

        // We set the content of this internal frame
        setContent( buildContentPanel() );
    }

    /**
     * Builds and answers the content panel.
     */
    private JComponent buildContentPanel() {
        GradientBackgroundPanel panel = new GradientBackgroundPanel( true );

        JEditorPane html = null;

        try {
            URL url = null;
            String path = null;
            path = "/docs/welcome.html";
            url = getClass().getResource( path );

            if ( url != null ) {
                html = new JEditorPane( url );
                html.setEditable( false );
                html.setOpaque( false );
                html.addHyperlinkListener( new HyperlinkListener() {
                    public void hyperlinkUpdate( HyperlinkEvent e ) {
                        if ( e.getEventType() == HyperlinkEvent.EventType.ACTIVATED ) {
                            BrowserLauncher.openURL( e.getURL().toString() );
                        }
                    }
                } );
            }
        } catch( Exception e ) {
            // We have a problem with the doc...
            throw new RuntimeException( e.getLocalizedMessage() );
        }

        panel.setLayout( new FormLayout( "left:1dlu:grow", "b:min:grow" ) );
        panel.add( html, new CellConstraints( 1, 1 ) );

        return UIFactory.createStrippedScrollPane( panel );
    }
}



